@@ -1,6 +1,7 @@
 """These are tests I have for pretty janky features of PyTabular.
+
 These were designed selfishly for my own uses.
-So seperating out, to one day sunset and remove.
+So seperating out... To one day sunset and remove.
 """
 from test.config import testing_parameters, testingtablename
 import pytest
@@ -8,6 +9,7 @@ import pytest
 
 @pytest.mark.parametrize("model", testing_parameters)
 def test_backingup_table(model):
+    """Tests model.backup_table()."""
     model.backup_table(testingtablename)
     assert (
         len(
@@ -23,6 +25,7 @@ def test_backingup_table(model):
 
 @pytest.mark.parametrize("model", testing_parameters)
 def test_revert_table2(model):
+    """Tests model.revert_table()."""
     model.revert_table(testingtablename)
     assert (
         len(
